#
# spec file for package kf6-kguiaddons
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kguiaddons

%bcond_without kde_python_bindings
%if %{with kde_python_bindings}
%if 0%{suse_version} > 1500
%define pythons %{primary_python}
%else
%{?sle15_python_module_pythons}
%endif
%define mypython %pythons
%define __mypython %{expand:%%__%{mypython}}
%define mypython_sitearch %{expand:%%%{mypython}_sitearch}
%endif

# Full KF6 version (e.g. 6.14.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kguiaddons
Version:        6.14.0
Release:        1.1
Summary:        Utilities for graphical user interfaces
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  pkgconfig(wayland-client) >= 1.15
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(wayland-protocols)
# SECTION bindings
%if %{with kde_python_bindings}
BuildRequires:  %{mypython}-build
BuildRequires:  %{mypython}-devel >= 3.9
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  cmake(Shiboken6)
BuildRequires:  cmake(PySide6)
%endif
# /SECTION
Requires:       libKF6GuiAddons6 = %{version}
# https://community.kde.org/Plasma/Plasma_6#Coinstallability
Provides:       kguiaddons = %{version}
Obsoletes:      kguiaddons < %{version}

%description
The KDE GUI addons provide utilities for graphical user interfaces in the areas
of colors, fonts, text, images, keyboard input.

%package -n libKF6GuiAddons6
Summary:        Utilities for graphical user interfaces
Requires:       kf6-kguiaddons >= %{version}

%description -n libKF6GuiAddons6
The KDE GUI addons provide utilities for graphical user interfaces in the areas
of colors, fonts, text, images, keyboard input.

%package imports
Summary:        QtQuick bindings for utilities for graphical user interfaces
Requires:       libKF6GuiAddons6 = %{version}

%description imports
The KDE GUI addons provide utilities for graphical user interfaces in the areas
of colors, fonts, text, images, keyboard input. This package provides QtQuick
bindings to use these GUI addons with QML and QtQuick applications.

%package devel
Summary:        Utilities for graphical user interfaces: Build Environment
Requires:       libKF6GuiAddons6 = %{version}

%description devel
The KDE GUI addons provide utilities for graphical user interfaces in the areas
of colors, fonts, text, images, keyboard input. Development files.

%if %{with kde_python_bindings}
%package -n python3-kf6-kguiaddons
Summary:        Python bindings for kf6-kguiaddons

%description -n python3-kf6-kguiaddons
This package provides Python bindings for kf6-kguiaddons.
%endif

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 \
  -DBUILD_QCH:BOOL=TRUE \
%if %{with kde_python_bindings}
  -DPython_EXECUTABLE:STRING=%{__mypython}
%endif
%{nil}

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%ldconfig_scriptlets -n libKF6GuiAddons6

%files
%{_kf6_applicationsdir}/google-maps-geo-handler.desktop
%{_kf6_applicationsdir}/openstreetmap-geo-handler.desktop
%{_kf6_applicationsdir}/wheelmap-geo-handler.desktop
%{_kf6_bindir}/kde-geo-uri-handler
%{_kf6_debugdir}/kguiaddons.categories

%files -n libKF6GuiAddons6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6GuiAddons.so.*

%files imports
%{_kf6_qmldir}/org/kde/guiaddons/

%files devel
%doc %{_kf6_qchdir}/KF6GuiAddons.*
%{_kf6_cmakedir}/KF6GuiAddons/
%{_kf6_includedir}/KGuiAddons/
%{_kf6_libdir}/libKF6GuiAddons.so
%{_kf6_pkgconfigdir}/KF6GuiAddons.pc

%if %{with kde_python_bindings}
%files -n python3-kf6-kguiaddons
%{mypython_sitearch}/*.so
%endif

%changelog
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * systemclipboard: Restore support for wlr-data-control separately
  * systemclipboard/WaylandClipboard: Port to ext-data-control
  * Update version to 6.14.0
  * systemclipboard: use QFile to write data to file descriptor
  * Remove code for no longer supported Qt versions
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * Add support for high-contrast mode on Windows
  * It compiles fine without qt6.9 deprecated methods
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Add KKeySequenceRecorder patterns
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * KIconUtils: simplify addOverlay implementation (kde#499363)
  * Fix build with Qt 6.10
  * Add xml/yaml linting
  * KIconUtils: correct the rendering of icons
  * Enable Python bindings on FreeBSD
  * CI: Add linux-qt6-next build
  * KIconUtils: take into account dpi for overlays
  * Lower Python requirement to 3.9
  * Remove qwant geo URI handler
  * [KColorSchemeWatcher] Fix reading XDG preference (kde#497790)
  * Update version to 6.11.0
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * systemclipboard: Cache mimetypes after retrieval (kde#497735)
  * Dont crash if the compostior doesnt support the shortcut inhibit protocol (kde#497457)
  * Bump PlasmaWaylandProtocols build dependency to 1.15.0 due to 333ba24
  * Update version to 6.10.0
  * [KColorSchemeWatcher] Fix reading XDG preference
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Bump PlasmaWaylandProtocols build dependency to 1.15.0
  * Update dependency version to 6.9.0
  * Add Python bindings
  * It compiles fine without deprecated methods
  * kmodifierkeyinfo: Update to v5 of the Wayland protocol (kde#483657)
  * Don't try to access QDBusMessage if not successful reply
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Add namespace for Android as required by newer gradle versions
  * Update version to 6.8.0
  * Add CI for static builds on Linux
  * Correctly install static QML modules
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * KCountryFlagEmoji: Improve fitting to the icon's bounding box
  * KCountryFlagEmoji: Fix emoji representation for non-country codes
  * KCountryFlagEmoji: Add test and demo cases for non-coutry codes
  * Fix window insets foreground coloring on older Android versions
  * Fix build with Qt < 6.7
  * Fix color luma computation for Android window insets
  * WaylandClipboard: fix QMimeData::urls() not working
  * Add QML bindings for KWindowInsetsControllert
  * Add KWindowInsetsController
  * WaylandClipboard: make sure format list doesn't have duplicate items
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Port towards QNativeInterface
  * Fail at CMake configure time if xcb Qt feature is not enabled
  * waylandclipboard: Dont explicitly clear when transfering sources
  * [kjobwidgets] Store window in a QPointer
  * ci: add Alpine/musl job
  * KOverlayIconEngine: Adjust to API change in Qt 6.8 in scaled pixmap hook
  * Generate wayland code with PRIVATE_CODE
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Add missing license text
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * KColorSchemeWatcherMac: update name in copyright
  * clipboard: Add roundtrip when setting clipboard (kde#466414)
  * support USE_DBUS option to enable/disable dbus use
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Deprecated KColorCollection
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * recorder/kkeysequencerecorder: conform to KKeyServer changes
  * gitignore: add VS Code dir
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * recorder/KKeySequenceRecorderPrivate: support recording multi-key modifier-only shortcuts
  * update version for new release
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kguiaddons
